@@ -29,5 +29,6 @@ class DataVarsInstall(DataVars):
 
     def importInstall(self, **args):
         """Import install variables"""
-        self.importData()
-        self.importData('calculate.install.variables')
+        self.importVariables()
+        self.importVariables('calculate.install.variables')
+        self.defaultModule = "install"
