@@ -414,8 +414,7 @@ class VariableClAutopartitionDevice(AutopartitionHelper,Variable):
     def check(self,valuelist):
         if self.Get('cl_autopartition_set') == "on":
             if not valuelist:
-                raise VariableError(_("For autopartition, please select "
-                                      "the install device"))
+                raise VariableError(_("For autopartition, please select the device"))
             useDisks = self.Select('os_disk_parent',
                                    where='os_disk_mount',ne='')
             for value in valuelist:
@@ -467,7 +466,7 @@ class VariableClAutopartitionScheme(AutopartitionHelper,Variable,AutoPartition):
 
     def init(self):
         self.help = _("autopartition options")
-        self.label = _("Autopartion options")
+        self.label = _("Autopartition options")
 
     def choice(self):
         return [
