@@ -431,6 +431,7 @@ class VariableOsDiskLvm(DeviceHelper,ReadonlyVariable):
     """
     LVM vgname and lvname
     """
+    type = "list"
     def get(self):
         """Get each element from var through udev [prop]"""
         return map(self.getLvmName,
@@ -594,7 +595,7 @@ class LocationHelper:
         """
         if self.Get('cl_autopartition_set') == "on":
             return \
-                _("Locations are not available with autopartitioning")
+                _("The layout is not available with autopartitioning")
         return ""
 
 class VariableOsLocationData(LocationHelper,TableVariable):
@@ -617,10 +618,10 @@ class VariableOsLocationData(LocationHelper,TableVariable):
                       "DIR directory. If set to 'none', the mount point will "
                       "not be moved. To create a bind mount point, you have "
                       "to specify the source directory as DISK")
-        self.label = _("Locations")
+        self.label = _("Layout")
 
     def set(self,value):
-        return sorted(value,key=lambda x:x[0])
+        return sorted(value,key=lambda x:x and x[0])
 
 class VariableOsLocationSource(LocationHelper,DeviceHelper,Variable):
     """
@@ -781,7 +782,8 @@ class VariableOsLocationDest(LocationHelper,Variable):
         ################################
         # check size for root device
         ################################
-        if self.Get('os_install_root_type') != "flash":
+        if self.Get('os_install_root_type') != "flash" and \
+            not "/usr" in value:
             for mp,size in filter(lambda x:x[0]=='/' and x[1].isdigit() and \
                                            int(x[1])<7*1024*1024*1024,
                                izip(value,
@@ -881,11 +883,9 @@ class VariableOsLocationDest(LocationHelper,Variable):
         if osInstallRootType == "flash":
             if filter(lambda x: x and x != '/', value):
                 raise VariableError(
-                    _("The Flash install is not supported for "
-                      "multipartition install"))
+                    _("Flash install does not support multipartition mode"))
             if filter(lambda x: x == "swap",value):
-                raise VariableError(_("The Flash install is not supported "
-                                      "for swap disks"))
+                raise VariableError(_("Flash install does not support swap disks"))
         ########################################
         # check install on member of RAID or LVM
         ########################################
@@ -896,8 +896,7 @@ class VariableOsLocationDest(LocationHelper,Variable):
                              installTypes)
             if memberData:
                 raise VariableError(
-                    _("Unable to use active {typepart} member {part} "
-                              "for installation").format(
+                    _("Unable to use {part} partition used by active {typepart}  for installation").format(
                               typepart=checkType.upper(),
                               part=memberData[0][0]))
 
@@ -962,7 +961,7 @@ class VariableOsLocationFormat(LocationHelper,Variable):
         for dev,mp,fs in devMpFs:
             if dev.startswith('/') and not dev.startswith('/dev/') and fs:
                 raise VariableError(
-                    _("Bind mount points does not use filesystem"))
+                    _("The bind mount point does not use filesystem"))
             # check compatible fs for mount point only root dirs
             if dev.startswith('/dev/') and mp and (mp.count('/') == 1 or
                         mp == '/var/calculate'):
@@ -971,7 +970,7 @@ class VariableOsLocationFormat(LocationHelper,Variable):
                     raise VariableError(
                         _("The filesystem for '%(mp)s' should not be '%(opt)s'")
                         %{'mp':mp, 'opt':fs}+" "+
-                        _("for the {typedisk} install").format(
+                        _("for {typedisk} install").format(
                             typedisk=osInstallRootType))
             if mp == "swap" and fs != "swap":
                 raise VariableError(
@@ -1017,7 +1016,7 @@ class VariableOsLocationPerformFormat(LocationHelper,Variable):
                             (self.Get('os_disk_mount'))))
         unavailFS = set(self.Select('os_format_type',
                                     where='os_format_use',
-                                    eq="off"))
+                                    eq="no"))
         fixNtfs = self.fixNtfs
         for dev,mp,fs,isformat in info:
             # should format if change fs or partition is root, but non flash
@@ -1031,7 +1030,7 @@ class VariableOsLocationPerformFormat(LocationHelper,Variable):
                 # partition use in current system
                 if diskMount.get(dev,''):
                     raise VariableError(
-                        _("{device}should, but cannot be formatted, as it is "
+                        _("{device} must but cannot be formatted, as it is "
                         "mounted to {mountpoint} on the current system").format(
                               device=dev,mountpoint=diskMount.get(dev,'')))
                 if isMount(dev):
@@ -1041,12 +1040,12 @@ class VariableOsLocationPerformFormat(LocationHelper,Variable):
                 # but user select non-format
                 if not self.isTrue(isformat):
                     raise VariableError(
-                        _("{device} should be formatted").format(
+                        _("{device} must be formatted").format(
                             device=dev))
             if self.isTrue(isformat):
                 if not mp:
                     raise VariableError(
-                        _("No need to format the unused device {dev}").format(
+                        _("No need to format unused device {dev}").format(
                             dev=dev))
                 if fs in unavailFS:
                     raise VariableError(
@@ -1054,6 +1053,11 @@ class VariableOsLocationPerformFormat(LocationHelper,Variable):
                 if not dev.startswith('/dev/'):
                     raise VariableError(
                         _("Bind mount points should not be formatted"))
+                elif diskMount.get(dev,"") and isformat:
+                    raise VariableError(
+                        _("{device} must but cannot be formatted, as it is mounted to {mountpoint} on the current system"
+                        ).format(
+                           device=dev,mountpoint=diskMount.get(dev,'')))
                 elif isMount(dev):
                     raise VariableError(
                         _("Please unmount disk {device} to "
@@ -1139,6 +1143,13 @@ class VariableClUuidSet(Variable):
         self.label = _("Use UUID")
         self.help = _("use UUID")
 
+    def uncompatible(self):
+        """
+        Unavailable for flash installation
+        """
+        if self.Get('os_install_root_type') == 'flash':
+            return _("Impossible to use UUID for Flash install")
+
 #############################################################
 # Install disk parameters
 #############################################################
@@ -1455,7 +1466,8 @@ class VariableOsInstallMbr(LocationHelper,Variable):
             # search /boot device or / device, by priority /boot,/
             if bootDevice:
                 return bootDevice
-        return self.Select('os_device_dev',where='os_device_type',eq='hdd')
+        return [self.Select('os_device_dev',where='os_device_type',eq='hdd',
+                           limit=1)]
 
     def choice(self):
         deviceParentMap = dict(self.ZipVars('os_device_dev','os_device_name'))
@@ -1472,7 +1484,7 @@ class VariableOsInstallMbr(LocationHelper,Variable):
         if rootType == "flash":
             if len(value) > 1:
                 raise VariableError(
-                    _("For the Flash install, you need only one disk"))
+                    _("For Flash install, you need only one disk"))
         for mbrDisk in value:
             if self.Get('cl_autopartition_set') == 'on':
                 tableOnBootDisk = self.Get('cl_autopartition_table')
@@ -1481,12 +1493,11 @@ class VariableOsInstallMbr(LocationHelper,Variable):
                         where="os_device_dev",eq=mbrDisk,limit=1)
             if not tableOnBootDisk:
                 raise VariableError(
-                    _("Disk '%s' need a partition table for the boot record")%
+                    _("Disk '%s' needs a partition table for the boot record")%
                       mbrDisk)
             if rootType == "flash":
                 if tableOnBootDisk == "gpt":
-                    raise VariableError(_("For the Flash install, you "
-                                          "need a disk with a dos table"))
+                    raise VariableError(_("You need a disk with a dos table for Flash install"))
         if value:
             if self.Get('os_grub2_path'):
                 self.checkForGrub2()
@@ -1502,7 +1513,7 @@ class VariableOsInstallMbr(LocationHelper,Variable):
                                  sort="DESC",limit=1)
         if "lvm-raid" in grubDiskType:
             raise VariableError(
-              _("Grub does not support booting from a RAID assembled from LVM")
+              _("Grub does not support booting from a RAID assembled from a LVM")
               + ". " +
                 _("Try to use a separate /boot partition"))
         if grubDiskType.count("raid")>1:
@@ -1523,8 +1534,7 @@ class VariableOsInstallMbr(LocationHelper,Variable):
                         sort="DESC",limit=1)
         if "lvm" in bootDiskType or "raid" in bootDiskType:
             raise ValueError(
-              _("Legacy grub requires a separate /boot partition to "
-                "support boot from RAID or LVM"))
+              _("Legacy grub requires a separate /boot partition to support boot from a RAID or a LVM"))
         if bootDiskFormat in ("btrfs","nilfs2"):
             raise ValueError(
               _("To support booting from %s, legacy grub needs a "
