@@ -25,6 +25,7 @@ from calculate.lib.utils.files import (readFile,getProgPath,process,
     readLinesFile)
 from calculate.lib.utils.common import getPasswdUsers,getUserGroups,getGroups
 from calculate.lib.utils.portage import isPkgInstalled
+from calculate.lib.utils.device import getUdevDeviceInfo
 from crypt import crypt
 from calculate.lib.encrypt import encrypt
 import calculate.lib.cl_template as cl_template
@@ -71,13 +72,20 @@ class VariableOsInstallScratch(Variable):
             # scratch not use for falsh and multipartition
             if self.Get('os_install_root_type') == "flash":
                 raise VariableError(
-                    _("The Flash install is not supported in the builder mode"))
+                    _("Flash install does not support the builder mode"))
             if filter(lambda x: not x in ('/','swap'), 
                       self.Get('os_install_disk_mount')):
                 raise VariableError(
                     _("The builder mode does not support "
                       "multipartition install"))
 
+    def uncompatible(self):
+        """
+        Unavailable for flash installation
+        """
+        if self.Get('os_install_root_type') == 'flash':
+            return _("Flash install does not support the builder mode")
+
 class VariableOsFormatType(ReadonlyVariable):
     """
     Filesystem format support by calcualte-install
@@ -98,10 +106,16 @@ class VariableOsFormatUse(ReadonlyVariable):
                 'type': "bool",
                 'value': "off"}
 
+    def checkFunc(self,fs):
+        if fs == "btrfs" and self.Get('os_root_type') == 'livecd':
+            return "no"
+        if "format" in FileSystemManager.supportFS[fs] and \
+               path.exists(FileSystemManager.supportFS[fs]["format"]):
+            return "yes"
+        return "no"
+
     def get(self):
-        return map(lambda x:"yes" 
-            if path.exists(FileSystemManager.supportFS[x]["format"])
-            else "no", self.Get('os_format_type'))
+        return map(self.checkFunc, self.Get('os_format_type'))
 
 class VariableClMigrateRootPwd(UserHelper,Variable):
     """
@@ -113,7 +127,7 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
     untrusted = True
 
     def init(self):
-        self.help = _("to specify root password")
+        self.help = _("specify the root password")
         self.label = _("Root password")
 
     def get(self):
@@ -146,7 +160,7 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
 
     def check(self,value):
         if not value:
-            raise PasswordError(_("Missed a password for user %s")%"root")
+            raise PasswordError(_("Password for user %s missing")%"root")
 
 class VariableClMigrateData(UserHelper,TableVariable):
     """
@@ -255,7 +269,7 @@ class VariableClMigrateUserPwd(UserHelper,Variable):
         for user,pwd in zip(self.Get('cl_migrate_user'),value):
             if not pwd:
                 raise PasswordError(
-                    _("Missed a password for user %s")%user)
+                    _("Password for user %s missing")%user)
 
     def set(self,value):
         """
@@ -358,20 +372,14 @@ class VariableOsInstallDevFrom(Variable):
     """
     Root device of previous installed os
     """
-    def get(self):
-        """Get from calculate2.env by default"""
-        try:
-            config = cl_template.iniParser('/etc/calculate/calculate2.env')
-            val = config.getVar('install','os_install_dev_from')
-            return val.encode('utf-8')
-        except:
-            pass
-        return ""
+    value = ""
 
     def set(self,value):
         """
         If device in calculate3.env dev_from not exists set ''
         """
+        if value:
+            value = getUdevDeviceInfo(name=value).get('DEVNAME',value)
         if value in self.Get('os_disk_dev'):
             return value
         else:
@@ -524,31 +532,8 @@ class VariableClLive(Variable):
     opt = ['--live']
 
     def init(self):
-        self.label = _("Configure only dynamic options")
-        self.help = _("configure only dynamic options")
-
-class VariableClTemplatesLocate(Variable):
-    """
-    Location templates
-    """
-    type = "choice-list"
-    value = ['overlay','local','remote','clt']
-    element = "selecttable"
-    opt = ["-l","--locate"]
-    metavalue = "TEMPLATES"
-    untrusted = True
-
-    def init(self):
-        self.label = _("Location templates")
-        self.help = _("select location for templates %s") \
-                      %"'overlay','local','remote','clt'"
-
-    def choice(self):
-        return [
-		('overlay',_('Overlay templates')),
-		('local',_('Local templates')),
-		('remote',_('Remote templates')),
-		('clt',_('clt templates'))]
+        self.label = _("Configure dynamic options only")
+        self.help = _("configure dynamic options only")
 
 class VariableOsInstallPxe(ReadonlyVariable):
     """
@@ -561,12 +546,11 @@ class VariableOsInstallPxe(ReadonlyVariable):
         if value == "on":
             if self.Get('os_linux_system') != "server":
                 raise VariableError(
-                    _("The PXE install is available for Calculate Directory "
-                      "Server only")+'.')
+                    _("PXE install is available for Calculate Directory Server only")+'.')
             for pkg in ['net-misc/dhcp','net-ftp/tftp-hpa','net-fs/nfs-utils']:
                 if not isPkgInstalled(pkg):
                     raise VariableError(
-                       _("For the PXE install, you need to install package %s")
+                       _("For PXE install, you need to install package %s")
                             %pkg)
             try:
                 config = cl_template.iniParser('/etc/calculate/calculate.env')
@@ -576,8 +560,7 @@ class VariableOsInstallPxe(ReadonlyVariable):
             except:
                 pass
             raise VariableError(
-                _("The PXE install is only available if the DHCP service has "
-                  "been configured first"))
+                _("PXE install is only available if the DHCP service has been configured first"))
 
 class VariableOsInstallPxePath(Variable):
     """
@@ -588,5 +571,5 @@ class VariableOsInstallPxePath(Variable):
     opt = ['--pxe-path']
 
     def init(self):
-        self.label = _("Path for installation")
-        self.help = _("path for the PXE install")
+        self.label = _("Installation path")
+        self.help = _("path for PXE install")
